@@ -12,7 +12,7 @@ from alerta.models.enums import Scope
 from alerta.models.metrics import Timer, timer
 from alerta.models.switch import Switch
 from alerta.utils.api import (assign_customer, process_action, process_alert,
-                              process_status)
+                              process_delete, process_status)
 from alerta.utils.audit import write_audit_trail
 from alerta.utils.paging import Page
 from alerta.utils.response import jsonp
@@ -289,10 +289,20 @@ def delete_alert(alert_id):
     if not alert:
         raise ApiError('not found', 404)
 
+    try:
+        deleted = process_delete(alert)
+    except RejectException as e:
+        write_audit_trail.send(current_app._get_current_object(), event='alert-delete-rejected', message=alert.text,
+                               user=g.login, customers=g.customers, scopes=g.scopes, resource_id=alert.id, type='alert',
+                               request=request)
+        raise ApiError(str(e), 400)
+    except Exception as e:
+        raise ApiError(str(e), 500)
+
     write_audit_trail.send(current_app._get_current_object(), event='alert-deleted', message='', user=g.login,
                            customers=g.customers, scopes=g.scopes, resource_id=alert.id, type='alert', request=request)
 
-    if alert.delete():
+    if deleted:
         return jsonify(status='ok')
     else:
         raise ApiError('failed to delete alert', 500)
