@@ -6,6 +6,7 @@ from alerta.auth.decorators import permission
 from alerta.exceptions import ApiError
 from alerta.models.enums import Scope
 from alerta.models.permission import Permission
+from alerta.settings import DEFAULT_ADMIN_ROLE
 from alerta.utils.audit import admin_audit_trail
 from alerta.utils.response import jsonp
 
@@ -22,7 +23,7 @@ def create_perm():
     except ValueError as e:
         raise ApiError(str(e), 400)
 
-    if perm.match in ['admin', 'user', 'guest']:
+    if perm.match in [DEFAULT_ADMIN_ROLE, 'user', 'guest']:
         raise ApiError('{} role already exists'.format(perm.match), 409)
 
     for want_scope in perm.scopes:
@@ -66,7 +67,7 @@ def list_perms():
     perms = Permission.find_all(query)
 
     admin_perm = Permission(
-        match='admin',
+        match=DEFAULT_ADMIN_ROLE,
         scopes=[Scope.admin]
     )
     user_perm = Permission(
